@@ -25,8 +25,8 @@
  * 桼
  *
  * $RCSfile: index.php,v $
- * $Revision: 1.2 $
- * $Date: 2010/06/10 05:12:31 $
+ * $Revision: 1.3 $
+ * $Date: 2010/06/22 05:30:54 $
  *
  **********************************************************/
 
@@ -115,7 +115,7 @@ if (isset($_POST["login"]) === TRUE) {
         if (sess_start($_POST["admin"], $_POST["passwd"], $sesskey) === TRUE) {
             result_log(":OK:󤷤ޤ");
             /* ֥եɹ */
-            if (read_tab_conf() === FALSE) {
+            if (read_tab_conf(ADMINTABCONF) === FALSE) {
                 $sys_err = TRUE;
                 $pg->display(NULL);
                 exit (1);
